@@ -27,19 +27,23 @@ export function createSearchAppInit(
   defaultComponents,
   autoInit = true,
   autoInitDataAttr = "invenio-search-config",
-  multi = false
+  multi = false,
+  ContainerComponent = React.Fragment,
 ) {
+
   const initSearchApp = (rootElement) => {
     const { appId, ...config } = JSON.parse(
       rootElement.dataset[_camelCase(autoInitDataAttr)]
     );
     loadComponents(appId, defaultComponents).then((res) => {
       ReactDOM.render(
-        <SearchApp
-          config={config}
-          // Use appName to namespace application components when overriding
-          {...(multi && { appName: appId })}
-        />,
+        <ContainerComponent>
+          <SearchApp
+            config={config}
+            // Use appName to namespace application components when overriding
+            {...(multi && { appName: appId })}
+          />
+        </ContainerComponent>,
         rootElement
       );
     });
